Metadata Module
===============

.. raw:: html

   <script src='https://storage.ko-fi.com/cdn/scripts/overlay-widget.js'></script>
   <script>
     kofiWidgetOverlay.draw('mrzahaki', {
       'type': 'floating-chat',
       'floating-chat.donateButton.text': 'Support me',
       'floating-chat.donateButton.background-color': '#2980b9',
       'floating-chat.donateButton.text-color': '#fff'
     });
   </script>



.. automodule:: sudio.metadata.metadata
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: sudio.metadata.audio_record_database
   :members:
   :undoc-members:
   :show-inheritance:
